featureflags.rest.api.default package
=====================================

Submodules
----------

featureflags.rest.api.default.authenticate module
-------------------------------------------------

.. automodule:: featureflags.rest.api.default.authenticate
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.get\_all\_segments module
-------------------------------------------------------

.. automodule:: featureflags.rest.api.default.get_all_segments
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.get\_evaluation\_by\_identifier module
--------------------------------------------------------------------

.. automodule:: featureflags.rest.api.default.get_evaluation_by_identifier
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.get\_evaluations module
-----------------------------------------------------

.. automodule:: featureflags.rest.api.default.get_evaluations
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.get\_feature\_config module
---------------------------------------------------------

.. automodule:: featureflags.rest.api.default.get_feature_config
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.get\_feature\_config\_by\_identifier module
-------------------------------------------------------------------------

.. automodule:: featureflags.rest.api.default.get_feature_config_by_identifier
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.api.default.stream module
-------------------------------------------

.. automodule:: featureflags.rest.api.default.stream
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: featureflags.rest.api.default
    :members:
    :undoc-members:
    :show-inheritance:
